fnss.adapters.mn.from_mininet — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.adapters.mn.from_mininet

`from_mininet`(topology)

  Convert a Mininet topology to an FNSS one.

  Parameters: | topology : Mininet Topo A Mininet topology object
  Returns: | topology : Topology An FNSS Topology object

### Navigation

- index
- modules |
- modules |
- next |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »